@@ -5,7 +5,7 @@ import logging
 LOGGER = logging.getLogger('pyShelly')
 
 NAME = "pyShelly"
-VERSION = "0.2.11"
+VERSION = "0.2.13"
 
 COAP_IP = "224.0.1.187"
 COAP_PORT = 5683
@@ -13,7 +13,7 @@ COAP_PORT = 5683
 MDNS_IP = "224.0.0.251"
 MDNS_PORT = 5353
 
-REGEX_VER = r"^20(\d{6}).+v(\d+\.\d+\.\d+(-rc\d)?)@"
+REGEX_VER = r"^20(\d{6}).+v(\d+\.\d+\.\d+(-rc\d)?)(_.*)?@"
 
 """Define constants for result from /status response from device"""
 STATUS_RESPONSE_RELAYS = 'relays'
@@ -81,6 +81,7 @@ INFO_VALUE_CURRENT = 'current'
 INFO_VALUE_TILT = 'tilt'
 INFO_VALUE_VIBRATION = 'vibration'
 INFO_VALUE_TEMP = 'temperature'
+INFO_VALUE_HUMIDITY = 'humidity'
 INFO_VALUE_ILLUMINANCE = 'illuminance'
 INFO_VALUE_GAS = 'gas'
 INFO_VALUE_SENSOR = 'sensor'
@@ -154,14 +155,15 @@ SHELLY_TYPES = {
     'SHIX3-1': {'name': "Shelly i3", 'mqtt':'shellyix3'},
     'SHGS-1': {'name': "Shelly Gas", 'mqtt':'shellygas'},
     'SHAIR-1': {'name': "Shelly Air", 'mqtt':'ShellyAir'},
-    'SHPLUG-U1': {'name': "Shelly Plug US", 'mqtt':'shellyplugu1'},
-    'SHUNI-1': {'name': "Shelly UNI", 'mqtt':'shellyuni'}
+    'SHPLG-U1': {'name': "Shelly Plug US", 'mqtt':'shellyplugu1'},
+    'SHUNI-1': {'name': "Shelly UNI", 'mqtt':'shellyuni'},
+    'SHSW-L': {'name': "Shelly 1L", 'mqtt':'shelly1l'}
 }
 
 EFFECTS_RGBW2 = [
     {'name': "Off", 'effect': 0},
     {'name': "Meteor shower", 'effect': 1},
-    {'name':"Gradual change", 'effect': 2},
+    {'name': "Gradual change", 'effect': 2},
     {'name': "Flash", 'effect': 3}
 ]
 
@@ -169,10 +171,10 @@ EFFECTS_BULB = [
     {'name': "Off", 'effect': 0},
     {'name': "Meteor shower", 'effect': 1},
     {'name': "Gradual change", 'effect': 2},
-    {'name':"Breath", 'effect': 3},
-    {'name':"Flash", 'effect': 4},
+    {'name': "Breath", 'effect': 3},
+    {'name': "Flash", 'effect': 4},
     {'name': "On/off gradual", 'effect': 5},
-    {'name':"Red/green change", 'effect': 6},
+    {'name': "Red/green change", 'effect': 6},
 ]
 
 RSSI_LEVELS = {
@@ -180,4 +182,4 @@ RSSI_LEVELS = {
     -60 : "very good",
     -70 : "good",
     -1000: "weak"
-}
\ No newline at end of file
+}
